
% THE SPIDER 
% 
% Core library objects. 
%   data         - Storing input data and output results 
%   data_global  - Implementation of data object that limits memory overhead
%   algorithm    - Generic algorithm object
%   group        - Groups sets of objects together (algorithms or data) 
%   loss         - Evaluates loss functions
%   get_mean     - Takes mean loss over groups of algs
%   chain        - Builds chains of objects: output of one to input of another
%   preimage     - calculates preimage of mappings in feature space
%   param        - To train and test different hyperparameters of an object
%   cv           - Cross validation using objects given data
%   kernel       - Evaluates and caches kernel functions
%   distance     - Evaluates and caches distance functions
%   wilcoxon     - Wilcoxon test of statistical significance of results
%   corrt_test   - Corrected resampled t-test - for dependent trials
%
% Pre-Processing objects
%   normalize    - Simple normalization of data
%   map          - General user specified mapping function of data
%
% Density Estimation objects.
%   parzen       - Parzen's windows kernel density estimator
%   indep        - Density estimator which assumes feature independence
%   bayes        - Classifer based on density estimation for each class
%   gauss        - Normal distribution density estimator
%                    
% Pattern Recognition objects.
%   svm          - Support Vector Machine (svm)
%   c45          - C4.5 for binary or multi-class 
%   knn          - k-nearest neighbours
%   platt        - Conditional Probability estimation for margin classifiers
%   anorm        - Minimize the a-norm in alpha space using kernels
%   l1           - Minimize l1 norm of w for a linear separator 
%   kde          - Kernel Dependency Estimation: general input/output machine
%
% Multi-Class and Multi-label objects. 
%   one_vs_rest  - Voting method of one against the rest (also for multi-label)
%   one_vs_one   - Voting method of one against one
%   mc_svm       - Multi-class SVM
%   c45          - C4.5 for binary or multi-class 
%   knn          - k-nearest neighbours
%               
% Feature Selection objects.
%   feat_sel     - Generic object for feature selection + classifier
%   r2w2_sel     - SVM Bound-based gradient descent selection
%   rfe          - Recursive Feature Elimination (also for the non-linear case)
%   l0           - Dual zero-norm minimization (Weston, Elisseeff)
%   fsv          - Primal zero-norm based feature selection (Mangasarian)
%   fisher       - Fisher criterion feature selection
%   mars         - selection algorithm of Friedman (greedy selection)
%   clustub      - Multi-class feature selection using spectral clustering
%      
% Regression objects.
%   svr          - Support Vector Regression
%   knn          - k-nearest neighbours
%   multi_reg    - meta method for independent multiple output regression
%   multi_rr     - (possibly multi-dimensional) ridge regression   
%   lms          - least mean squared regression [now obselete due to multi_rr]
%   kmp          - kernel matching pursuit
%   kpls         - kernel partial least squares
%
% Model Selection objects.
%   gridsel      - select parameters from a grid of values 
%   r2w2_sel     - Selecting SVM parameters by generalization bound
%
% Unsupervised objects.
%   one_class_svm- One class SVM
%   kmeans       - K means clustering
%   kpca         - Kernel Principal Components Analysis
%   nmf          - Non-negative Matrix factorization
%   spectral     - Spectral clustering
%                             
% Semi-Supervised objects.
%   trans_marg   - Transduction by adding points far from margin
% 
% See also help on: demos, train, test.







