function a = mrank(hyper) 
%
% MRANK Manifold ranking object             
%  
% a = mrank(hyperParam) 
%
% Generates an mrank object with given hyperparameters.
%
%
%   Hyperparameters (with defaults)
%   child=kernel('rbf')  -- the kernel is stored as a member called "child"
%   alpha=0.99           -- parameter governing convergence rate
%   iterations=600       -- number of iterations of algorithm
%   use_edge_graph=0     -- if turned on, sparsify kernel using edge graph
%   normalize=0          -- normalize in the input space? 1 yes, 0 no
%   standardize=[]       -- centre and standardize data? 1 yes, 0 no
%                           default behaviour is to do so, except for
%                           linear and polynomial-based kernels
%                           (good for maintaining sparsity).
% Methods:
%    train, test, plot
% 
%    [DAT, A] = TRAIN(A, DAT);
% 
%    Points with Y=0 within DAT are considered unlabelled, and points with
%    non-zero Y are the query points. The unlabelled points are ranked
%    according to their similarity to the query points, computed via an
%    iterative spreading activation network algorithm. DAT.Y on exit
%    contains [I S R] where I is the original index, S the ranking score
%    and R the rank of each point. Results can be plotted with
%    PLOTRANKING(DAT.Y, DAT.X) or PLOT(A).  If no labels are given, the
%    data are simply stored within A awaiting a TEST.
% 
%    DAT = TEST(A, DAT)
% 
%    Takes the data previously stored in A during training, and removes any
%    points which were previously labelled (previous query points). Then
%    uses DAT as a new query and returns the results for the unlabelled data
%    only, in the same format as that from TRAIN.
% 
%    PLOT(A) -- see HELP MRANK/PLOT

  %<<------hyperparam initialisation------------->> 
  a.child = kernel('rbf');
  a.alpha = 0.99;
  a.iterations=600;
  a.use_edge_graph = 0;  
  a.normalize=0;
  a.standardize = [];
  
  
  % <<-------------results----------------->> 
  a.dat = [];
  a.edge_graph=[];
  a.result = [];
  a.convergence = [];
  a.mst = [];
  
  algoType=algorithm('mrank');
  a= class(a,'mrank',algoType);

  a.algorithm.alias={'kern','child'}; % kernel aliases
  
 if nargin==1,
    eval_hyper;
 end;
