function a = clustub(hyper)
% CLUSTUB clustub object
%  
% A=CLUSTUB(H) returns a clustub object initialized with hyperparameters H. 
%
%  Peforms feature selection via spectral clustering.
%
% Hyperparameters, and their defaults
%  feat=[]              -- number of features
%  output_rank=0        -- set to 1 if only the feature ranking matters
%                          (does not perform any classification on the data)
%  child=spectral('k=2')-- Clustering method used for training
%
% Model
%  w                    -- the weights
%  b0                   -- the threshold (when using all features)
%  rank                 -- the ranking of the features
%  d                    -- training set
%
% Methods:
%  train, test, get_w 
%
% Note:
%  Method for multi-class feature selection.
%  To use with SVM, use:  
%  chain(clustub('output_rank=1'),one_vs_rest(svm))
  a.feat=[]; % number of features 
  a.output_rank=0; % don't output labels, output selected features 
  a.child=spectral('k=2');  
  % model           
  a.w=[];
  a.b0=0;
  a.rank=[];
  a.d=[];
  
  p=algorithm('clustub');
  a= class(a,'clustub',p);
  if nargin==1
    eval_hyper;
  end  
  
