function a = rfe(c,hyper)     

% RFE recursive feature elimination object
%   
% A=RFE(C,[H]) returns an rfe object initialized with base algorithm
% C (usually an svm) and hyperparameters H. 
%
% RFE selects features via greedy backward selection, it trains a
% base algorithm, and calls the method get_w of the base algorithm
% and removes the feature(s) with the smallest absolute value returned
% from this method. get_w in a linear svm for example returns the
% weights for each dimension defining the hyperplane. Base algorithms
% with a method get_w include: one_vs_one, one_vs_rest, lda, stab, svm, svr
% 
%  Hyperparameters, and their defaults
%
%   feat=[]        -- number of selected features to be selected, if feat=0, 
%                     then the minimum number of feature will be computed.
%   speed=0        -- rfe only removes a single feature each iteration 
%                     if less than (speed) features left, otherwise it
%                     halves the number of features each iteration.
%   output_rank=0  -- whether a ranking is desired, if set to 0 then a
%                     classification is perfomed after feature selection.
%   child=svm      -- The base classifier to be used at each step
%
%  Model
%
%  a.rank=[]       -- ranking of features
%  a.child=svm     -- base classifier trained at end of process
%
%  Methods:
%   train, test


% data=rfe(algorithm)
  % runs rfe on a given algorithm (default=linear binary svm)
  % requires an algorithm which has a function get_w
    
  %hyperparams
  a.feat=[];       % number of features 
  a.speed=0;       % rfe only removes a single feature if less than
                   % speed features left 
  a.output_rank=0; % output labels, not selected features 
    
  % model
  a.rank=[];
  if nargin==0
    a.child=svm;  
  else 
    a.child=c; %% algorithm to use  
  end
  
  p=algorithm('rfe');
  a= class(a,'rfe',p);
  if nargin==2
    eval_hyper;
  end  
  
